@@ -34,6 +34,7 @@ impl From<&Metadata> for Date {
 impl Date {
     pub fn render(&self, colors: &Colors, flags: &Flags) -> ColoredString {
         let now = Local::now();
+        #[allow(deprecated)]
         let elem = match self {
             &Date::Date(modified) if modified > now - Duration::hours(1) => Elem::HourOld,
             &Date::Date(modified) if modified > now - Duration::days(1) => Elem::DayOld,
@@ -46,6 +47,7 @@ impl Date {
         let locale = current_locale();
 
         if let Date::Date(val) = self {
+            #[allow(deprecated)]
             match &flags.date {
                 DateFlag::Date => val.format("%c").to_string(),
                 DateFlag::Locale => val.format_localized("%c", locale).to_string(),
@@ -119,6 +121,7 @@ mod test {
         let mut file_path = env::temp_dir();
         file_path.push("test_an_hour_old_file_color.tmp");
 
+        #[allow(deprecated)]
         let creation_date = Local::now() - chrono::Duration::seconds(4);
 
         let success = cross_platform_touch(&file_path, &creation_date)
@@ -146,6 +149,7 @@ mod test {
         let mut file_path = env::temp_dir();
         file_path.push("test_a_day_old_file_color.tmp");
 
+        #[allow(deprecated)]
         let creation_date = Local::now() - chrono::Duration::hours(4);
 
         let success = cross_platform_touch(&file_path, &creation_date)
@@ -173,6 +177,7 @@ mod test {
         let mut file_path = env::temp_dir();
         file_path.push("test_a_several_days_old_file_color.tmp");
 
+        #[allow(deprecated)]
         let creation_date = Local::now() - chrono::Duration::days(2);
 
         let success = cross_platform_touch(&file_path, &creation_date)
@@ -200,6 +205,7 @@ mod test {
         let mut file_path = env::temp_dir();
         file_path.push("test_with_relative_date.tmp");
 
+        #[allow(deprecated)]
         let creation_date = Local::now() - chrono::Duration::days(2);
 
         let success = cross_platform_touch(&file_path, &creation_date)
@@ -285,6 +291,7 @@ mod test {
         let mut file_path = env::temp_dir();
         file_path.push("test_iso_format_year_old.tmp");
 
+        #[allow(deprecated)]
         let creation_date = Local::now() - Duration::days(400);
         let success = cross_platform_touch(&file_path, &creation_date)
             .unwrap()
@@ -343,7 +350,7 @@ mod test {
     #[test]
     #[cfg(all(not(windows), target_arch = "x86_64"))]
     fn test_bad_date() {
-        // 4437052 is the bad year taken from https://github.com/Peltoche/lsd/issues/529 that we know is both
+        // 4437052 is the bad year taken from https://github.com/lsd-rs/lsd/issues/529 that we know is both
         // a) high enough to break chrono
         // b) not high enough to break SystemTime (as Duration::MAX would)
         let end_time = std::time::SystemTime::UNIX_EPOCH
